 

bias_lvls = [400, 1000, 1600, 2150]; % needs to be read in manually from the *.avi file.
biases = numel(bias_lvls);

deltaT = fullData(2, 2, 1) - fullData(1, 2, 1);
dists = -16.8  + fullData(:, 2, 1) * 1e-9 * (3*10^8 / 2) / 1.36; %from NS to seconds to meters / refraction index

num_peaks = 1;
num_rounds = floor(size(fullData, 3) / biases);

peaks = zeros(num_rounds, num_peaks);
inten_vals = zeros(num_rounds, num_peaks);

for k = 1:num_rounds
    index_start = (k-1) * biases;
    bias_index = 1;

    [peaks(k), inten_vals(k)] = find_one_peak(fullData(450:end, 1, index_start + bias_index), deltaT);
 
end

attenuation = 10 * log(inten_vals/max(inten_vals));
peak_dists = dists(peaks + 500);

figure(2)
hold on
plot(dists(peaks + 500), attenuation, '.b', 'MarkerSize', 16)
h = plot(att_fit);
h.LineWidth = 2;
xlabel('Depth below sea level (m)')
ylabel('Attenuation (dB)')
legend('Data points', 'Linear fit')
axis([-inf inf -inf 5])
set(gca,'FontSize',20)
plottools('on')
saveas(gcf, 'boat_att.eps', 'epsc');
savefig(strcat('boat_att', '.fig'));



% Find highest peaks in data (based on Ver 4)
function [peak, val] = find_one_peak(trace, deltaT)

nanoSecDepth = size(trace, 1);

maxPoint = round(2.8 / deltaT);

%detect locations of interest
tempPeaks = trace((maxPoint+1):end) - trace(1:nanoSecDepth - maxPoint);
[~, peak] = max(tempPeaks);

val = trace(peak + maxPoint) - trace(peak);

end


